# -*- coding: cp1252 -*-
"""Common filenames and locations for topographic data, meshes and outputs.
"""

from os import sep, environ, getenv, getcwd
from os.path import expanduser
import sys
from time import localtime, strftime, gmtime
from anuga.utilities.polygon import read_polygon, plot_polygons, is_inside_polygon, number_mesh_triangles
#from anuga.coordinate_transforms.redfearn import degminsec2decimal_degrees, convert_points_from_latlon_to_utm
from anuga.utilities.system_tools import get_user_name

# file and system info
#---------------------------------
codename = 'project.py'

home = getenv('INUNDATIONHOME') #Sandpit's parent dir   
user = get_user_name()

# INUNDATIONHOME is the inundation directory, not the data directory.
home += sep +'data'

#time stuff
time = strftime('%Y%m%d_%H%M%S',localtime()) #gets time for new dir
gtime = strftime('%Y%m%d_%H%M%S',gmtime()) #gets time for new dir
build_time = time+'_build'
run_time = time+'_run'
print 'gtime: ', gtime

tide = 0

#Making assumptions about the location of scenario data
state = 'western_australia'
scenario_name = 'broome'
scenario = 'broome_tsunami_scenario_2006'

# onshore data provided by WA DLI
onshore_name = 'Broome_topography_DLI' # original

#island
#island_name = 'rott_dli_ext' # original

# offshore
coast_name = 'Broome_coastline'

offshore_name = 'Broome_Bathymetry'
offshore_name1 = 'inferred_north'
offshore_name2 = 'inferred_south'

#final topo name
combined_name ='broome_combined_elevation'
combined_small_name = 'broome_combined_elevation_small'

topographies_in_dir = home+sep+state+sep+scenario+sep+'elevation_final'+sep+'points'+sep+'Feb07'+sep
topographies_dir = home+sep+state+sep+scenario+sep+'anuga'+sep+'topographies'+sep
topographies_time_dir = topographies_dir+build_time+sep

#input topo file location
onshore_in_dir_name = topographies_in_dir + onshore_name
#island_in_dir_name = topographies_in_dir + island_name

coast_in_dir_name = topographies_in_dir + coast_name

offshore_in_dir_name = topographies_in_dir + offshore_name
offshore_in_dir_name1 = topographies_in_dir + offshore_name1
offshore_in_dir_name2 = topographies_in_dir + offshore_name2

onshore_dir_name = topographies_dir + onshore_name

#island_dir_name = topographies_dir + island_name

coast_dir_name = topographies_dir + coast_name

offshore_dir_name = topographies_dir + offshore_name
offshore_dir_name1 = topographies_dir + offshore_name1
offshore_dir_name2 = topographies_dir + offshore_name2

#final topo files
combined_dir_name = topographies_dir + combined_name
combined_small_name_dir = topographies_dir + combined_small_name

meshes_dir = home+sep+state+sep+scenario+sep+'anuga'+sep+'meshes'+sep
meshes_dir_name = meshes_dir + scenario_name

polygons_dir = home+sep+state+sep+scenario+sep+'anuga'+sep+'polygons'+sep
tide_dir = home+sep+state+sep+scenario+sep+'anuga'+sep+'tide_data'+sep


boundaries_source = '????'
#boundaries locations
boundaries_in_dir = home+sep+state+sep+scenario+sep+'anuga'+sep+'boundaries'+sep+'urs'+sep+boundaries_source+sep
boundaries_in_dir_name = boundaries_in_dir + scenario_name
boundaries_dir = home+sep+state+sep+scenario+sep+'anuga'+sep+'boundaries'+sep
boundaries_dir_name = boundaries_dir + scenario_name
#boundaries_time_dir = home+sep+state+sep+scenario+sep+'anuga'+sep+'boundaries'+sep+build_time+sep
#boundaries_time_dir_name = boundaries_time_dir + boundaries_name  #Used by post processing

#output locations
output_dir = home+sep+state+sep+scenario+sep+'anuga'+sep+'outputs'+sep
output_build_time_dir = home+sep+state+sep+scenario+sep+'anuga'+sep+'outputs'+sep+build_time+sep
output_run_time_dir = home+sep+state+sep+scenario+sep+'anuga'+sep+'outputs'+sep+run_time+sep
output_run_time_dir_name = output_run_time_dir + scenario_name  #Used by post processing

#gauges
gauge_name = 'broome_gauges.csv'
gauges_dir = home+sep+state+sep+scenario+sep+'anuga'+sep+'gauges'+sep
gauges_dir_name = gauges_dir + gauge_name

community_filename = gauges_dir + 'CHINS_v2.csv'
community_broome = gauges_dir + 'community_broome.csv'

#buildings_filename = gauges_dir + 'broome_res_nexis.csv'
buildings_filename_damage_out = 'broome_res_nexis_modified.csv'

###############################
# Domain definitions
###############################
from anuga.utilities.polygon import read_polygon, plot_polygons, polygon_area, is_inside_polygon

poly_all = read_polygon(polygons_dir+'extent.csv')
res_poly_all = 150000

###############################
# Interior region definitions
###############################

poly_0 = read_polygon(polygons_dir+'neg20_coast_contour_pts.csv')
res_0 = 10000
poly_1 = read_polygon(polygons_dir+'broome_north_coast_inside_extent.csv')
res_1 = 5000

poly_2 = read_polygon(polygons_dir+'broome_south_coast_inside_extent.csv')
res_2 = 5000

poly_3 = read_polygon(polygons_dir+'Broome_town_pts.csv')
res_3 = 2000

poly_4 = read_polygon(polygons_dir+'Broome_inner_town_pts.csv')
res_4 = 500
#assert zone == refzone

interior_regions = [[poly_0,res_0],[poly_1,res_1],[poly_2,res_2]
                     ,[poly_3,res_3],[poly_4,res_4]]

trigs_min = number_mesh_triangles(interior_regions, poly_all, res_poly_all)

print 'min number triangles', trigs_min

###################################################################
# Clipping regions for export to asc and regions for clipping data
###################################################################

# exporting asc grid
eastingmin = 406215.87
eastingmax = 440208.78
northingmin = 7983427.73
northingmax = 8032834.52



